@@ -71,8 +71,10 @@ class MapfwBenchmarker:
                     def solve_func(problem):
                         try:
                             sol = func_timeout(self.timeout / 1000, self.solver, args=(problem,))
-                        except:
+                        except FunctionTimedOut:
                             sol = None
+                        except Exception as e:
+                            print("ERROR: "+e)
                         return sol
                 else:
                     def solve_func(problem):
